@@ -1,6 +1,6 @@
-#! /bin/sh
+#! @SHELL@
 # autoheader -- create `config.h.in' from `configure.in'
-# Copyright (C) 1992, 1993, 1994, 1996 Free Software Foundation, Inc.
+# Copyright (C) 1992, 1993, 1994, 1996, 1998 Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -194,9 +194,9 @@ if test -n "$syms"; then
   # Some fgrep's have limits on the number of lines that can be in the
   # pattern on the command line, so use a temporary file containing the
   # pattern.
-  (fgrep_tmp=${TMPDIR-/tmp}/autoh$$
+  (fgrep_tmp=`/bin/mktemp ${TMPDIR-/tmp}/autoh$$.XXXXXX`
    trap "rm -f $fgrep_tmp; exit 1" 1 2 15
-   cat > $fgrep_tmp <<EOF
+   cat >> $fgrep_tmp <<EOF
 $syms
 EOF
    fgrep -f $fgrep_tmp
@@ -241,6 +241,10 @@ if test -n "$libs"; then
   done
 fi
 
+if test -n "$verbatim"; then
+  echo "$verbatim"
+fi
+
 # Handle the case where @BOTTOM@ is the first line of acconfig.h.
 test -r $localdir/acconfig.h &&
   grep @BOTTOM@ $localdir/acconfig.h >/dev/null &&
